# Decoder

::: flyvis.task.decoder.ActivityDecoder

::: flyvis.task.decoder.DecoderGAVP

::: flyvis.task.decoder.init_decoder

::: flyvis.task.decoder.Conv2dHexSpace

::: flyvis.task.decoder.Conv2dConstWeight

::: flyvis.task.decoder.GlobalAvgPool
